# Multiscale-actin

A Vivarium wrapper for ReaDDy actin models.

## Installation

Install conda: https://docs.conda.io/en/latest/miniconda.html
(`conda` is currently required to install `readdy`.)

1. Create a virtual environment with conda-specific dependencies: `conda env create -f environment.yml`
2. Activate the environment: `conda activate multiscale-actin`
3. Install with pip dependencies: `pip install multiscale_actin` (or install in editable mode: `pip install -e .`)
